@@ -60,6 +60,14 @@ class Pingdom(object):
         else:
             raise Exception("Invalid method in pingdom request")
 
+        # Store pingdom api limits
+        self.shortlimit = response.headers.get(
+            'Req-Limit-Short',
+            self.shortlimit)
+        self.longlimit = response.headers.get(
+            'Req-Limit-Long',
+            self.longlimit)
+
         # Verify OK response
         if response.status_code != 200:
             sys.stderr.write('ERROR from %s: %d' % (response.url,
@@ -67,10 +75,6 @@ class Pingdom(object):
             sys.stderr.write('Returned data: %s\n' % response.json())
             response.raise_for_status()
 
-        # Store pingdom api limits
-        self.shortlimit = response.headers['Req-Limit-Short']
-        self.longlimit = response.headers['Req-Limit-Long']
-
         return response
 
     def actions(self, **parameters):
@@ -1245,7 +1249,7 @@ class Pingdom(object):
                 sys.stderr.write("'%s'" % key + ' is not a valid argument ' +
                                  'of newSharedReport()\n')
 
-        parameters = {'checkid': name, 'sharedtype': 'banner'}
+        parameters = {'checkid': checkid, 'sharedtype': 'banner'}
         for key, value in kwargs.iteritems():
             parameters[key] = value
 
